#include <bits/stdc++.h>
using namespace std;

struct Point {
    int x, y, id = -1;

    Point operator -(const Point& other) {
        Point result;
        result.x = x - other.x;
        result.y = y - other.y;
        return result;
    }

    Point& operator -=(const Point& other) {
        x -= other.x;
        y -= other.y;
        return *this;
    }

    long long operator *(const Point& other) const {
        return 1LL * x * other.y - 1LL * y * other.x;
    }

    bool InUpperPart() const {
        return y > 0 || (y == 0 && x > 0);
    }
};

long long sign(long long x) {
    return x < 0 ? -1 : +1;
}

vector<int> GetOrder(vector<Point> points, Point a, Point b, long long s) {
    for (auto& point: points) {
        point -= a;
    }

    b -= a;
    points.push_back(b);
    sort(points.begin(), points.end(), [&](const Point& a, const Point& b) {
        if (a.InUpperPart() != b.InUpperPart()) {
            return a.InUpperPart() > b.InUpperPart();
        }

        return sign(a * b) == s;
    });

    for (int i = 0; i < (int) points.size() - 1; ++i) {
        if (points[i].id < 0) {
            rotate(points.begin(), points.begin() + i + 1, points.end());
            break;
        }
    }

    points.pop_back();
    vector<int> result;
    for (auto& point: points) {
        result.push_back(point.id);
    }

    return result;
}

struct FenwichTree {
    int n;
    vector<int> fenwick;

    FenwichTree(int n): n(n), fenwick(n + 1) {}

    void Inc(int position) {
        for (int i = position + 1; i <= n; i += i & -i)
            ++fenwick[i];
    }

    int Sum(int position) {
        int r = 0;
        for (int i = position + 1; i > 0; i -= i & -i)
            r += fenwick[i];
        
        return r;
    }
};

long long CountInversions(const vector<int>& a) {
    long long result = 0;
    int n = (int) a.size();
    FenwichTree fenwick(n);
    for (int e: a) {
        result += fenwick.Sum(n - 1) - fenwick.Sum(e);
        fenwick.Inc(e);
    }

    return result;
}

long long CountBelow(vector<Point> points, Point a, Point b, bool triangle) {
    int n = static_cast<int>(points.size());

    vector<Point> pts;
    Point diff = a - b;
    for (int i = 0; i < n; ++i) {
        if (diff * (points[i] - b) > 0) {
            pts.push_back(points[i]);
            pts.back().id = (int) pts.size() - 1;
        }
    }

    points = pts;
    n = static_cast<int>(points.size());

    auto first_order = GetOrder(points, a, b, +1);
    auto second_order = GetOrder(points, b, a, +1);

    //cout << "FIRST: "; for (int e: first_order) cout << e << ' '; cout << endl;
    //cout << "SECOND: "; for (int e: second_order) cout << e << ' '; cout << endl;

    vector<int> p(n);
    for (int i = 0; i < n; ++i) {
        p[first_order[i]] = i;
    }

    for (int i = 0; i < n; ++i) {
        second_order[i] = p[second_order[i]];
    }

    auto result = CountInversions(second_order);
    if (!triangle) {
        result = 1LL * n * (n - 1) / 2 - result;
    }
    //cout << "INVERSIONS: " << inversions << endl;
    return result;
}

void Solve() {
    int n;
    cin >> n;

    vector<Point> polygon(n);
    for (auto& point: polygon) {
        cin >> point.x >> point.y;
    }

    int m;
    cin >> m;

    vector<Point> points(m);
    int ids = 0;
    for (auto& point: points) {
        cin >> point.x >> point.y;
        point.id = ids++;
    }

    int q;
    cin >> q;
    for (int i = 0; i < q; ++i) {
        int a, b;
        cin >> a >> b;
        int next_a = a + 1;
        int next_b = (b + 1) % n;   

        long long result = 0;
        if (a + 1 == b) {
            result -= CountBelow(points, polygon[a], polygon[b], false);
            result -= CountBelow(points, polygon[b], polygon[next_b], false);
            result += CountBelow(points, polygon[a], polygon[next_b], false);
            result += 1LL * m * (m - 1) / 2;
        } else {
            result += CountBelow(points, polygon[next_a], polygon[b], false);
            result -= CountBelow(points, polygon[a], polygon[b], false);
            result -= CountBelow(points, polygon[next_a], polygon[next_b], false);
            result += CountBelow(points, polygon[a], polygon[next_b], false);
        }

        cout << result << ' ';
    }

    cout << '\n';
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;
    for (int i = 0; i < t; ++i) {
        Solve();
    }
}